@@ -4,7 +4,10 @@ import sys
 from revolut.utils import get_jwt
 
 if len(sys.argv) < 4:
-    print("Usage: {:s} <prvkey.pem> <issuer> <client_id>".format(sys.argv[0]), file=sys.stderr)
+    print(
+        "Usage: {:s} <prvkey.pem> <issuer> <client_id>".format(sys.argv[0]),
+        file=sys.stderr,
+    )
     sys.exit(1)
 
 prvkey = open(sys.argv[1], "rb").read()
